athlete_count: Query For Counting Athletes Per Team

Description Usage Arguments Value

View source: R/athlete_query.R

Description

Get a count of athletes by team.

Usage

1
athlete_count(con, team_name)

Arguments

con

A database connection.

team_name

A character vector with the name of an NCAA swimming conference.

Value

a data frame with the count on athletes by gender


warlicks/swimming_app documentation built on May 4, 2019, 12:59 a.m.